@@ -1,6 +1,6 @@
 from views import ReportAPIDispatchView
 
-from django.conf.urls.defaults import *
+from django.conf.urls import *
 from django.conf import settings
 
 
